pub struct DummyInteractionChip<SC> {
pub air: DummyInteractionAir,
/* private fields */
}Expand description
Note: in principle, committing cached trace is out of scope of a chip. But this chip is for testing, so we support it for convenience.
Fields
air: DummyInteractionAirImplementations
Sourceimpl<SC> DummyInteractionChip<SC>
impl<SC> DummyInteractionChip<SC>
pub fn new_without_partition( field_width: usize, is_send: bool, bus_index: BusIndex, ) -> Self
pub fn new_with_partition( config: SC, field_width: usize, is_send: bool, bus_index: BusIndex, ) -> Self
pub fn load_data(&mut self, data: DummyInteractionData)
pub fn air(&self) -> AirRef<SC>where
SC: StarkProtocolConfig,
Sourceimpl<SC: StarkProtocolConfig> DummyInteractionChip<SC>
impl<SC: StarkProtocolConfig> DummyInteractionChip<SC>
pub fn generate_proving_ctx(&self) -> AirProvingContext<CpuColMajorBackend<SC>>
Sourceimpl<SC: StarkProtocolConfig> DummyInteractionChip<SC>
impl<SC: StarkProtocolConfig> DummyInteractionChip<SC>
pub fn generate_traces_with_partition( &self, data: DummyInteractionData, ) -> AirProvingContext<CpuColMajorBackend<SC>>